@@ -303,12 +303,12 @@ class QA:
                 issues += self._check_resource_issues(resource)
 
             # 3. Check is instance is stuck in a stale status
-            if len(stale_resources) == 0:
-                logger.warning("Trying to call qainit to force QA update...")
-                self._qainit.force_update(response["list"]["hash"])
-                issues.append(
-                    "Your QA was in a stale status and has been fixed, launch `suite-py describe` again please."
-                )
+            # if len(stale_resources) == 0:
+            #     logger.warning("Trying to call qainit to force QA update...")
+            #     self._qainit.force_update(response["list"]["hash"])
+            #     issues.append(
+            #         "Your QA was in a stale status and has been fixed, launch `suite-py describe` again please."
+            #     )
 
         return issues
 
